@@ -61,7 +61,7 @@ def pylog(test_options=None):
     """Main entry point for script."""
     version = ver_check()
     options = test_options or docopt(__doc__, version=version)
-    set_global_verbosity_level(options.get('--verbose'))
+    _set_global_verbosity_level(options.get('--verbose'))
     lgr.debug(options)
     pylog_run(options)
 
