@@ -5,6 +5,9 @@ import logging
 import os
 from abc import abstractmethod, ABCMeta
 
+# import pretty table for statistical data visualization
+from prettytable import PrettyTable
+
 # FILE DEFAULTS
 DEFAULT_FILE_PATH = 'generated.log'
 DEFAULT_MAXBYTES = 10000000
@@ -36,48 +39,8 @@ class BaseTransport(object):
         return
 
 
-class UDPTransport(BaseTransport):
-    def __init__(self, config):
-        try:
-            self.host = config['host']
-            self.port = config['port']
-        except KeyError as ex:
-            raise('configuration not complete: {}'.format(ex))
-
-    def configure(self):
-        logger = logging.getLogger('pylog')
-        handler = logging.handlers.DatagramHandler(self.host, self.port)
-        logger.addHandler(handler)
-        logger.setLevel(logging.DEBUG)
-        return logger
-
-    def send(self, client, log):
-        # getattr(logger, level)(message)
-        client.debug(log)
-
-    def close(self):
-        pass
-
-
-class StreamTransport(BaseTransport):
-    def __init__(self, config):
-        pass
-
-    def configure(self):
-        logger = logging.getLogger('pylog')
-        handler = logging.handlers.StreamHandler()
-        logger.addHandler(handler)
-        logger.setLevel(logging.DEBUG)
-        return logger
-
-    def send(self, client, log):
-        client.debug(log)
-
-    def close(self):
-        pass
-
-
 class FileTransport(BaseTransport):
+    """a RotatingFileHandler transport implementation"""
     def __init__(self, config):
         self.file_path = config.get('file', DEFAULT_FILE_PATH)
         self.max_bytes = config.get('max_bytes', DEFAULT_MAXBYTES)
@@ -101,12 +64,25 @@ class FileTransport(BaseTransport):
         pass
 
     def get_data(self):
-        # TODO: fix bug where rotating files will return a bad line count
+        # https://code.google.com/p/prettytable/wiki/Tutorial
+        # you can also get data from csv's, htmls, etc...
+        # so for instance, you could query elasticsearch right here,
+        # get the data, and write it here, so that you can make sure
+        # all logs you wrote actually made it through.
+        data_table = PrettyTable(["Type", "Value"])
+        # make sure the "type" field is always aligned to the left.
+        data_table.align["Type"] = "l"
+        # ...
+        data_table.padding_width = 1
         with open(self.file_path) as f:
-            return 'lines written to file: {}'.format(sum(1 for _ in f))
+            # populate the table
+            # TODO: fix bug where rotating files will return a bad line count
+            data_table.add_row(["lines written", sum(1 for _ in f)])
+        return data_table
 
 
 class AmqpTransport(BaseTransport):
+    """an amqp transport implementation"""
     def __init__(self, config):
         try:
             self.host = config['host']
@@ -138,3 +114,46 @@ class AmqpTransport(BaseTransport):
     # TODO: support connection closing
     def close(self):
         self.connection.close()
+
+
+class UDPTransport(BaseTransport):
+    """a udp transport implementation"""
+    def __init__(self, config):
+        try:
+            self.host = config['host']
+            self.port = config['port']
+        except KeyError as ex:
+            raise('configuration not complete: {}'.format(ex))
+
+    def configure(self):
+        logger = logging.getLogger('pylog')
+        handler = logging.handlers.DatagramHandler(self.host, self.port)
+        logger.addHandler(handler)
+        logger.setLevel(logging.DEBUG)
+        return logger
+
+    def send(self, client, log):
+        # getattr(logger, level)(message)
+        client.debug(log)
+
+    def close(self):
+        pass
+
+
+class StreamTransport(BaseTransport):
+    """a shell stream transport implementation"""
+    def __init__(self, config):
+        pass
+
+    def configure(self):
+        logger = logging.getLogger('pylog')
+        handler = logging.StreamHandler()
+        logger.addHandler(handler)
+        logger.setLevel(logging.DEBUG)
+        return logger
+
+    def send(self, client, log):
+        client.debug(log)
+
+    def close(self):
+        pass
